@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import sys
 import functools
+import inspect
 
 PY2 = sys.version_info[0] == 2
 
@@ -70,7 +71,7 @@ class Arg(object):
     """
     def __init__(self, type_=None, default=None, required=False,
                  validate=None, use=None, multiple=False, error=None,
-                 allow_missing=False):
+                 allow_missing=False, target=None):
         self.type = type_ or noop  # default to no type conversion
         if multiple and default is None:
             self.default = []
@@ -84,6 +85,7 @@ class Arg(object):
         if required and allow_missing:
             raise ValueError('"required" and "allow_missing" cannot both be True.')
         self.allow_missing = allow_missing
+        self.target = target
 
     def _validate(self, value):
         """Perform conversion and validation on ``value``."""
@@ -113,8 +115,6 @@ class Arg(object):
         else:
             return self._validate(value)
 
-DEFAULT_TARGETS = ('querystring', 'form', 'json',)
-
 
 class Parser(object):
     """Base parser class that provides high-level implementation for parsing
@@ -126,6 +126,7 @@ class Parser(object):
     :param tuple targets: Default targets to parse.
     :param callable error_handler: Custom error handler function.
     """
+    DEFAULT_TARGETS = ('querystring', 'form', 'json',)
 
     #: Maps target => method name
     TARGET_MAP = {
@@ -137,9 +138,9 @@ class Parser(object):
         'files': 'parse_files',
     }
 
-    def __init__(self, targets=DEFAULT_TARGETS, error_handler=None):
-        self.targets = targets
-        self.error_handler = _callable(error_handler)
+    def __init__(self, targets=None, error_handler=None):
+        self.targets = targets or self.DEFAULT_TARGETS
+        self.error_callback = _callable(error_handler)
 
     def _validated_targets(self, targets):
         """Ensure that the given targets argument is valid.
@@ -156,6 +157,20 @@ class Parser(object):
             raise ValueError(msg)
         return targets
 
+    def _get_value(self, name, argobj, req, target):
+        # Parsing function to call
+        # May be a method name (str) or a function
+        func = self.TARGET_MAP.get(target)
+        if func:
+            if inspect.isfunction(func):
+                function = func
+            else:
+                function = getattr(self, func)
+            value = function(req, name, argobj)
+        else:
+            value = None
+        return value
+
     def parse_arg(self, name, argobj, req, targets=None):
         """Parse a single argument.
 
@@ -167,11 +182,13 @@ class Parser(object):
         :return: The argument value.
         """
         value = None
+        if argobj.target:
+            value = self._get_value(name, argobj, req=req, target=argobj.target)
+            if value is not None:
+                return argobj.validated(value)
+
         for target in self._validated_targets(targets or self.targets):
-            method_name = self.TARGET_MAP.get(target)
-            if method_name:
-                method = getattr(self, method_name)
-                value = method(req, name, argobj)
+            value = self._get_value(name, argobj, req=req, target=target)
             if argobj.multiple and not (isinstance(value, list) and len(value)):
                 continue
             # Found the value; validate and return it
@@ -208,12 +225,12 @@ class Parser(object):
                     parsed[argname] = parsed_value
             return parsed
         except Exception as error:
-            if self.error_handler:
-                self.error_handler(error)
+            if self.error_callback:
+                self.error_callback(error)
             else:
                 self.handle_error(error)
 
-    def use_args(self, argmap, req=None, targets=DEFAULT_TARGETS, as_kwargs=False):
+    def use_args(self, argmap, req=None, targets=None, as_kwargs=False):
         """Decorator that injects parsed arguments into a view function or method.
 
         Example usage with Flask: ::
@@ -227,6 +244,7 @@ class Parser(object):
         :param tuple targets: Where on the request to search for values.
         :param bool as_kwargs: Whether to insert arguments as keyword arguments.
         """
+        targets = targets or self.DEFAULT_TARGETS
         def decorator(func):
             @functools.wraps(func)
             def wrapper(*args, **kwargs):
@@ -258,6 +276,49 @@ class Parser(object):
         kwargs['as_kwargs'] = True
         return self.use_args(*args, **kwargs)
 
+    def target_handler(self, name):
+        """Decorator that registers a function that parses a request target.
+        The wrapped function receives a request, the name of the argument, and
+        the :class:`Arg <webargs.core.Arg>` object.
+
+        Example: ::
+
+            from webargs import core
+            parser = core.Parser()
+
+            @parser.target_handler('name')
+            def parse_data(request, name, arg):
+                return request.data.get(name)
+
+        :param str name: The name of the target to register.
+        """
+        def decorator(func):
+            self.TARGET_MAP[name] = func
+            return func
+        return decorator
+
+    def error_handler(self, func):
+        """Decorator that registers a custom error handling function. The
+        function should received the raised error. Overrides
+        the parser's ``handle_error`` method.
+
+        Example: ::
+
+            from webargs import core
+            parser = core.Parser()
+
+            class CustomError(Exception):
+                pass
+
+            @parser.error_handler
+            def handle_error(error):
+                raise CustomError(error)
+
+        :param callable func: The error callback to register.
+        """
+        self.error_callback = func
+        return func
+
     # Abstract Methods
 
     def parse_json(self, req, name, arg):
